@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -63,7 +63,8 @@ class CloudFilestoreManagerClientMeta(type):
     _transport_registry["grpc_asyncio"] = CloudFilestoreManagerGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[CloudFilestoreManagerTransport]:
         """Returns an appropriate transport class.
 
@@ -192,10 +193,16 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return self._transport
 
     @staticmethod
-    def backup_path(project: str, location: str, backup: str,) -> str:
+    def backup_path(
+        project: str,
+        location: str,
+        backup: str,
+    ) -> str:
         """Returns a fully-qualified backup string."""
         return "projects/{project}/locations/{location}/backups/{backup}".format(
-            project=project, location=location, backup=backup,
+            project=project,
+            location=location,
+            backup=backup,
         )
 
     @staticmethod
@@ -208,10 +215,16 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def instance_path(project: str, location: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        location: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/locations/{location}/instances/{instance}".format(
-            project=project, location=location, instance=instance,
+            project=project,
+            location=location,
+            instance=instance,
         )
 
     @staticmethod
@@ -224,7 +237,9 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -237,9 +252,13 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -248,9 +267,13 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -259,9 +282,13 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -270,10 +297,14 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -459,7 +490,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         r"""Lists all instances in a project for either a
         specified location or for all locations.
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
@@ -542,12 +572,20 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInstancesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -636,7 +674,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -658,7 +701,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         capacity of the backup (and also equal to or larger than
         the minimum capacity of the tier).
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
@@ -762,7 +804,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -881,7 +928,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -908,7 +960,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         larger than the capacity of the backup (and also equal
         to or larger than the minimum capacity of the tier).
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
@@ -972,7 +1023,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1087,7 +1143,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1112,7 +1173,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         r"""Lists all backups in a project for either a specified
         location or for all locations.
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
@@ -1194,12 +1254,20 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListBackupsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1288,7 +1356,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1414,7 +1487,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1529,7 +1607,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1646,7 +1729,12 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1675,7 +1763,9 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-filestore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-filestore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
