@@ -249,8 +249,7 @@ class CloudFilestoreManagerGrpcTransport(CloudFilestoreManagerTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -590,5 +589,9 @@ class CloudFilestoreManagerGrpcTransport(CloudFilestoreManagerTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("CloudFilestoreManagerGrpcTransport",)
